@@ -21,14 +21,14 @@ cpanm QBit::Application::Model::DB
 
 =item *
 
-apt-get install libqbit-application-model-db-perl (http://perlhub.ru/)
+cpanm https://github.com/QBitFramework/QBit-Application-Model-DB.git
 
 =back
 
 =cut
 
 package QBit::Application::Model::DB;
-$QBit::Application::Model::DB::VERSION = '0.028';
+$QBit::Application::Model::DB::VERSION = '0.029';
 use qbit;
 
 use base qw(QBit::Application::Model);
